# Changelog
All notable changes to this project will be documented in this file.


## [Unreleased]

### Fixed
- Command line interface:
    - `list-settings`: improved display of types and default values
### Changed
- WIP: Handling settings of dependency flow during `Settings` validation.
### Removed

### Added
- Tool: ecppll (nextpnr's Lattice ECP5 PLL tool)
- Examples: ULX3S adopted DVI test from EMARD
  - change LED chaser speed with buttons `5` and `6`!
- Examples: improved version of `blinky` for the ULX3S board in VHDL
  - change LED chaser speed with buttons `5` and `6`!

## [v0.1.0-alpha.11] - 2022-04-16


[Unreleased]: https://github.com/XedaHQ/xeda/compare/v0.1.0-alpha.1...HEAD
[v0.1.0-alpha.11]: https://github.com/XedaHQ/xeda/releases/tag/v0.1.0-alpha.11